# from infection_monkey.exploit.powershell_utils.auth_options import AuthOptions
from infection_monkey.exploit.powershell_utils.auth_options import (
    AUTH_BASIC,
    AUTH_NEGOTIATE,
    AUTH_NTLM,
    ENCRYPTION_AUTO,
    ENCRYPTION_NEVER,
    get_auth_options,
)
from infection_monkey.exploit.powershell_utils.credentials import Credentials, SecretType

CREDENTIALS_WITH_PASSWORD = Credentials("user1", "password1", SecretType.PASSWORD)
CREDENTIALS_EMPTY_PASSWORD = Credentials("user2", "", SecretType.PASSWORD)
CREDENTIALS_NONE_PASSWORD = Credentials("user3", None, SecretType.CACHED)
CREDENTIALS_LM_HASH = Credentials("user4", "LM_HASH:NONE", SecretType.LM_HASH)
CREDENTIALS_NT_HASH = Credentials("user5", "NONE:NT_HASH", SecretType.NT_HASH)


def test_get_auth_options__ssl_true_with_password():
    auth_options = get_auth_options(CREDENTIALS_WITH_PASSWORD, use_ssl=True)

    assert auth_options.ssl


def test_get_auth_options__ssl_true_empty_password():
    auth_options = get_auth_options(CREDENTIALS_EMPTY_PASSWORD, use_ssl=True)

    assert not auth_options.ssl


def test_get_auth_options__ssl_true_none_password():
    auth_options = get_auth_options(CREDENTIALS_NONE_PASSWORD, use_ssl=True)

    assert auth_options.ssl


def test_get_auth_options__ssl_false_with_password():
    auth_options = get_auth_options(CREDENTIALS_WITH_PASSWORD, use_ssl=False)

    assert not auth_options.ssl


def test_get_auth_options__ssl_false_empty_password():
    auth_options = get_auth_options(CREDENTIALS_EMPTY_PASSWORD, use_ssl=False)

    assert not auth_options.ssl


def test_get_auth_options__ssl_false_none_password():
    auth_options = get_auth_options(CREDENTIALS_NONE_PASSWORD, use_ssl=False)

    assert not auth_options.ssl


def test_get_auth_options__auth_type_with_password():
    auth_options = get_auth_options(CREDENTIALS_WITH_PASSWORD, use_ssl=False)

    assert auth_options.auth_type == AUTH_NEGOTIATE


def test_get_auth_options__auth_type_empty_password():
    auth_options = get_auth_options(CREDENTIALS_EMPTY_PASSWORD, use_ssl=False)

    assert auth_options.auth_type == AUTH_BASIC


def test_get_auth_options__auth_type_none_password():
    auth_options = get_auth_options(CREDENTIALS_NONE_PASSWORD, use_ssl=False)

    assert auth_options.auth_type == AUTH_NEGOTIATE


def test_get_auth_options__auth_type_with_LM_hash():
    auth_options = get_auth_options(CREDENTIALS_LM_HASH, use_ssl=False)

    assert auth_options.auth_type == AUTH_NTLM


def test_get_auth_options__auth_type_with_NT_hash():
    auth_options = get_auth_options(CREDENTIALS_NT_HASH, use_ssl=False)

    assert auth_options.auth_type == AUTH_NTLM


def test_get_auth_options__encryption_with_password():
    auth_options = get_auth_options(CREDENTIALS_WITH_PASSWORD, use_ssl=False)

    assert auth_options.encryption == ENCRYPTION_AUTO


def test_get_auth_options__encryption_empty_password():
    auth_options = get_auth_options(CREDENTIALS_EMPTY_PASSWORD, use_ssl=False)

    assert auth_options.encryption == ENCRYPTION_NEVER


def test_get_auth_options__encryption_none_password():
    auth_options = get_auth_options(CREDENTIALS_NONE_PASSWORD, use_ssl=False)

    assert auth_options.encryption == ENCRYPTION_AUTO
